//   Copyright 2022 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//

import QtQuick 2.6
import QtQuick.Controls 2.2
import Esri.display_a_map 1.0

Item {

    // Create MapQuickView here, and create its Map etc., in C++ code
    MapView {
        id: view
        anchors.fill: parent
        // set focus to enable keyboard navigation
        focus: true
    }

    // Declare the C++ instance that creates the map etc., and supply the view.
    Display_a_map {
        id: model
        mapView: view
    }

    ComboBox {
        id: queryComboBox
        anchors {
            left: parent.left
            top: parent.top
            margins: 15
        }

        property int bestWidth: implicitWidth
        width: bestWidth + indicator.width + leftPadding + rightPadding
        model: ["Choose a SQL where clause",
            "UseType = 'Government'",
            "UseType = 'Residential'",
            "UseType = 'Irrigated Farm'",
            "TaxRateArea = 10853",
            "TaxRateArea = 10860",
            "Roll_LandValue > 1000000",
            "Roll_LandValue < 1000000"]

        onCurrentTextChanged: {
            model.runQuery(queryComboBox.currentText)
        }
    }

}


